@@ -49,7 +49,7 @@ class Foreman::Engine::CLI < Foreman::Engine
 
   def startup
     @colors = map_colors
-    proctitle "foreman: master" unless Foreman.windows?
+    proctitle "foreman: main" unless Foreman.windows?
     Color.enable($stdout, options[:color])
   end
 
@@ -77,7 +77,7 @@ private
     @name_padding ||= begin
       index_padding = @names.values.map { |n| formation[n] }.max.to_s.length + 1
       name_padding  = @names.values.map { |n| n.length + index_padding }.sort.last
-      [ 6, name_padding ].max
+      [ 6, name_padding.to_i ].max
     end
   end
 
